import { 
    select, 
    csv, 
    scaleLinear, 
    max, 
    scaleBand, 
    axisLeft,
    axisBottom
} from 'd3'

const svg = select('svg')
const height = +svg.attr('height');//parseFloat
const width = +svg.attr('width');

const render = data=> {
    const xValue = d => d.population;
    const yValue = d => d.country;
    const margin={top: 20, right: 40, bottom: 20, left: 100};
    const innerwidth= width-margin.left-margin.right;
    const innerheight= height-margin.top-margin.bottom;

    const xScale = scaleLinear()
        .domain([0, max(data, xValue)])
        .range([0, innerwidth]);

    const yScale = scaleBand()
        .domain(data.map(yValue))
        .range([0, innerheight])
        .padding(0.1);

//the margin convention
    const g = svg.append('g')
        .attr('transform', `translate(${margin.left},${margin.top})`);
    //adding axis
    g.append('g').call(axisLeft(yScale));
    g.append('g').call(axisBottom(xScale))
        .attr('transform', `translate(0,${innerheight})`);

    g.selectAll('rect').data(data)//create a D3 data join
     .enter().append('rect')
     .attr('y', d=> yScale(yValue(d)))
  	 .attr('width',d => xScale(xValue(d)))
  	 .attr('height',yScale.bandwidth());
};

csv('https://v1.vizhub.com/singularity6033/datasets/data.csv').then(data => {
  	data.forEach(d=>{
    	d.population = +d.population * 1000;//make the population become numbers
    });
    render(data);
});


